#ifndef EXTCONF_H
#define EXTCONF_H
#define HAVE_RB_EXT_RACTOR_SAFE 1
#define HAVE__RB_FIBER_TRANSFER 1
#define HAVE_SYS_EPOLL_H 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_SYS_EVENTFD_H 1
#define HAVE_RB_IO_DESCRIPTOR 1
#define HAVE__RB_PROCESS_STATUS_WAIT 1
#define HAVE_RB_FIBER_CURRENT 1
#define HAVE__RB_FIBER_RAISE 1
#define HAVE_EPOLL_PWAIT2 1
#define HAVE_RUBY_IO_BUFFER_H 1
#endif
